SpaceMatrix

Struct SpaceMatrix 

pub struct SpaceMatrix { /* private fields */ }
A general finite metric space with color classes.

  • Distances are given by a symmetric distance matrix of size nxn,
  • Colors are given by a list of size n,
  • Implements the ColoredMetric trait.

Implementations

Source

impl SpaceMatrix

pub fn new(distances: Vec<Vec<f32>>, colors: Vec<usize>) -> SpaceMatrix

Creates a new SpaceMatrix.

Input
  • distances has to be a 2D-vector that represents a quadratic matrix satisfying the metric properties (symmetry, non-negativity, identity of indiscernibles and the triangle inequality),
  • colors is a vector that stores the color of each point.

The running time of asserting the metric properties is O(n3).

Panics
  • Panics, if distances is not a quadratic matrix.
  • Panics, if the length of the color classes does not match the number of points given by distances.
  • Panics, if distances does not satisfy the metric properties.
pub fn new_by_array<const N: PointCount>( distances: [[f32; N]; N], colors: [usize; N], ) -> SpaceMatrix

Creates a new SpaceMatrix as in new but the distances and color data are received by arrays.

Example
use ff_k_center::{Point,SpaceMatrix,ColoredMetric};
let space = SpaceMatrix::new_by_array(
                [[0.0, 2.0, 1.5],
                 [2.0, 0.0, 0.6],
                 [1.5, 0.6, 0.0]], [0, 0, 1]);
let points : Vec<&Point> = space.point_iter().collect();
assert!(space.is_metric());
assert_eq!(space.dist(points[1],points[2]),0.6);
assert_eq!(space.color(points[2]),1);
assert_eq!(space.n(),3);